# Generated by roxygen2: do not edit by hand

S3method(print,modlr)
export(compare_models)
export(johnson_neyman)
export(moderated_regression)
export(plot_moderation)
export(simple_slopes)
importFrom(broom,tidy)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme)
importFrom(lmtest,coeftest)
importFrom(rlang,.data)
importFrom(sandwich,vcovHC)
importFrom(stats,AIC)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,df.residual)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,sd)
importFrom(stats,update)
importFrom(stats,vcov)
